==> eam-wshub-proxyclient-11.4-8-sources.jar: org/openapplications/oagis_segments/DATETIMEqual.java <==

package org.openapplications.oagis_segments;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour DATETIMEqual.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * <p>
 * <pre>
 * &lt;simpleType name="DATETIMEqual">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="ACCOUNTING"/>
 *     &lt;enumeration value="ACTEND"/>
 *     &lt;enumeration value="ACTSTART"/>
 *     &lt;enumeration value="APPREQ"/>
 *     &lt;enumeration value="APPROVAL"/>
 *     &lt;enumeration value="AVAILABLE"/>
 *     &lt;enumeration value="BKTEND"/>
 *     &lt;enumeration value="BKTSTART"/>
 *     &lt;enumeration value="CANCEL"/>
 *     &lt;enumeration value="CHANGEDATE"/>
 *     &lt;enumeration value="COMPDATE"/>
 *     &lt;enumeration value="CONSUME"/>
 *     &lt;enumeration value="CREATION"/>
 *     &lt;enumeration value="CUMULATIVE"/>
 *     &lt;enumeration value="DELIVACT"/>
 *     &lt;enumeration value="DELIVSCHED"/>
 *     &lt;enumeration value="DISCNT"/>
 *     &lt;enumeration value="DOCUMENT"/>
 *     &lt;enumeration value="DUE"/>
 *     &lt;enumeration value="EARLSTEFF"/>
 *     &lt;enumeration value="EARLSTSHIP"/>
 *     &lt;enumeration value="EFFECTIVE"/>
 *     &lt;enumeration value="ENGCHG"/>
 *     &lt;enumeration value="EXECFINISH"/>
 *     &lt;enumeration value="EXECSTART"/>
 *     &lt;enumeration value="EXPIRATION"/>
 *     &lt;enumeration value="FAILDATE"/>
 *     &lt;enumeration value="FORECASTF"/>
 *     &lt;enumeration value="FORECASTS"/>
 *     &lt;enumeration value="FROM"/>
 *     &lt;enumeration value="GENERATION"/>
 *     &lt;enumeration value="JOBDUE"/>
 *     &lt;enumeration value="IMPL"/>
 *     &lt;enumeration value="INVOICE"/>
 *     &lt;enumeration value="LABORFINSH"/>
 *     &lt;enumeration value="LABORSTART"/>
 *     &lt;enumeration value="LASTUSED"/>
 *     &lt;enumeration value="LOADING"/>
 *     &lt;enumeration value="MATCHING"/>
 *     &lt;enumeration value="MSMENTDATE"/>
 *     &lt;enumeration value="NEEDDELV"/>
 *     &lt;enumeration value="OPFINISH"/>
 *     &lt;enumeration value="OPSTART"/>
 *     &lt;enumeration value="PAYEND"/>
 *     &lt;enumeration value="PLANEND"/>
 *     &lt;enumeration value="PLANSTART"/>
 *     &lt;enumeration value="PO"/>
 *     &lt;enumeration value="PROMDELV"/>
 *     &lt;enumeration value="PROMSHIP"/>
 *     &lt;enumeration value="PYMTTERM"/>
 *     &lt;enumeration value="RECEIVED"/>
 *     &lt;enumeration value="REPORTDATE"/>
 *     &lt;enumeration value="REPORTNGFN"/>
 *     &lt;enumeration value="REPORTNGST"/>
 *     &lt;enumeration value="REQUIRED"/>
 *     &lt;enumeration value="RESORCDWNF"/>
 *     &lt;enumeration value="RESORCDWNS"/>
 *     &lt;enumeration value="RSPDDATE"/>
 *     &lt;enumeration value="RSPDOCGEN"/>
 *     &lt;enumeration value="SCHEND"/>
 *     &lt;enumeration value="SCHSTART"/>
 *     &lt;enumeration value="SETUPFINSH"/>
 *     &lt;enumeration value="SETUPSTART"/>
 *     &lt;enumeration value="SHIP"/>
 *     &lt;enumeration value="SHIPSCHED"/>
 *     &lt;enumeration value="STATUSDATE"/>
 *     &lt;enumeration value="TEARDOWNF"/>
 *     &lt;enumeration value="TEARDOWNS"/>
 *     &lt;enumeration value="TO"/>
 *     &lt;enumeration value="OTHER"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "DATETIMEqual")
@XmlEnum
public enum DATETIMEqual {

    ACCOUNTING,
    ACTEND,
    ACTSTART,
    APPREQ,
    APPROVAL,
    AVAILABLE,
    BKTEND,
    BKTSTART,
    CANCEL,
    CHANGEDATE,
    COMPDATE,
    CONSUME,
    CREATION,
    CUMULATIVE,
    DELIVACT,
    DELIVSCHED,
    DISCNT,
    DOCUMENT,
    DUE,
    EARLSTEFF,
    EARLSTSHIP,
    EFFECTIVE,
    ENGCHG,
    EXECFINISH,
    EXECSTART,
    EXPIRATION,
    FAILDATE,
    FORECASTF,
    FORECASTS,
    FROM,
    GENERATION,
    JOBDUE,
    IMPL,
    INVOICE,
    LABORFINSH,
    LABORSTART,
    LASTUSED,
    LOADING,
    MATCHING,
    MSMENTDATE,
    NEEDDELV,
    OPFINISH,
    OPSTART,
    PAYEND,
    PLANEND,
    PLANSTART,
    PO,
    PROMDELV,
    PROMSHIP,
    PYMTTERM,
    RECEIVED,
    REPORTDATE,
    REPORTNGFN,
    REPORTNGST,
    REQUIRED,
    RESORCDWNF,
    RESORCDWNS,
    RSPDDATE,
    RSPDOCGEN,
    SCHEND,
    SCHSTART,
    SETUPFINSH,
    SETUPSTART,
    SHIP,
    SHIPSCHED,
    STATUSDATE,
    TEARDOWNF,
    TEARDOWNS,
    TO,
    OTHER;

    public String value() {
        return name();
    }

    public static DATETIMEqual fromValue(String v) {
        return valueOf(v);
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: org/openapplications/oagis_segments/DATETIMEqual.java <==

package org.openapplications.oagis_segments;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for DATETIMEqual.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="DATETIMEqual">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="ACCOUNTING"/>
 *     &lt;enumeration value="ACTEND"/>
 *     &lt;enumeration value="ACTSTART"/>
 *     &lt;enumeration value="APPREQ"/>
 *     &lt;enumeration value="APPROVAL"/>
 *     &lt;enumeration value="AVAILABLE"/>
 *     &lt;enumeration value="BKTEND"/>
 *     &lt;enumeration value="BKTSTART"/>
 *     &lt;enumeration value="CANCEL"/>
 *     &lt;enumeration value="CHANGEDATE"/>
 *     &lt;enumeration value="COMPDATE"/>
 *     &lt;enumeration value="CONSUME"/>
 *     &lt;enumeration value="CREATION"/>
 *     &lt;enumeration value="CUMULATIVE"/>
 *     &lt;enumeration value="DELIVACT"/>
 *     &lt;enumeration value="DELIVSCHED"/>
 *     &lt;enumeration value="DISCNT"/>
 *     &lt;enumeration value="DOCUMENT"/>
 *     &lt;enumeration value="DUE"/>
 *     &lt;enumeration value="EARLSTEFF"/>
 *     &lt;enumeration value="EARLSTSHIP"/>
 *     &lt;enumeration value="EFFECTIVE"/>
 *     &lt;enumeration value="ENGCHG"/>
 *     &lt;enumeration value="EXECFINISH"/>
 *     &lt;enumeration value="EXECSTART"/>
 *     &lt;enumeration value="EXPIRATION"/>
 *     &lt;enumeration value="FAILDATE"/>
 *     &lt;enumeration value="FORECASTF"/>
 *     &lt;enumeration value="FORECASTS"/>
 *     &lt;enumeration value="FROM"/>
 *     &lt;enumeration value="GENERATION"/>
 *     &lt;enumeration value="JOBDUE"/>
 *     &lt;enumeration value="IMPL"/>
 *     &lt;enumeration value="INVOICE"/>
 *     &lt;enumeration value="LABORFINSH"/>
 *     &lt;enumeration value="LABORSTART"/>
 *     &lt;enumeration value="LASTUSED"/>
 *     &lt;enumeration value="LOADING"/>
 *     &lt;enumeration value="MATCHING"/>
 *     &lt;enumeration value="MSMENTDATE"/>
 *     &lt;enumeration value="NEEDDELV"/>
 *     &lt;enumeration value="OPFINISH"/>
 *     &lt;enumeration value="OPSTART"/>
 *     &lt;enumeration value="PAYEND"/>
 *     &lt;enumeration value="PLANEND"/>
 *     &lt;enumeration value="PLANSTART"/>
 *     &lt;enumeration value="PO"/>
 *     &lt;enumeration value="PROMDELV"/>
 *     &lt;enumeration value="PROMSHIP"/>
 *     &lt;enumeration value="PYMTTERM"/>
 *     &lt;enumeration value="RECEIVED"/>
 *     &lt;enumeration value="REPORTDATE"/>
 *     &lt;enumeration value="REPORTNGFN"/>
 *     &lt;enumeration value="REPORTNGST"/>
 *     &lt;enumeration value="REQUIRED"/>
 *     &lt;enumeration value="RESORCDWNF"/>
 *     &lt;enumeration value="RESORCDWNS"/>
 *     &lt;enumeration value="RSPDDATE"/>
 *     &lt;enumeration value="RSPDOCGEN"/>
 *     &lt;enumeration value="SCHEND"/>
 *     &lt;enumeration value="SCHSTART"/>
 *     &lt;enumeration value="SETUPFINSH"/>
 *     &lt;enumeration value="SETUPSTART"/>
 *     &lt;enumeration value="SHIP"/>
 *     &lt;enumeration value="SHIPSCHED"/>
 *     &lt;enumeration value="STATUSDATE"/>
 *     &lt;enumeration value="TEARDOWNF"/>
 *     &lt;enumeration value="TEARDOWNS"/>
 *     &lt;enumeration value="TO"/>
 *     &lt;enumeration value="OTHER"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "DATETIMEqual")
@XmlEnum
public enum DATETIMEqual {

    ACCOUNTING,
    ACTEND,
    ACTSTART,
    APPREQ,
    APPROVAL,
    AVAILABLE,
    BKTEND,
    BKTSTART,
    CANCEL,
    CHANGEDATE,
    COMPDATE,
    CONSUME,
    CREATION,
    CUMULATIVE,
    DELIVACT,
    DELIVSCHED,
    DISCNT,
    DOCUMENT,
    DUE,
    EARLSTEFF,
    EARLSTSHIP,
    EFFECTIVE,
    ENGCHG,
    EXECFINISH,
    EXECSTART,
    EXPIRATION,
    FAILDATE,
    FORECASTF,
    FORECASTS,
    FROM,
    GENERATION,
    JOBDUE,
    IMPL,
    INVOICE,
    LABORFINSH,
    LABORSTART,
    LASTUSED,
    LOADING,
    MATCHING,
    MSMENTDATE,
    NEEDDELV,
    OPFINISH,
    OPSTART,
    PAYEND,
    PLANEND,
    PLANSTART,
    PO,
    PROMDELV,
    PROMSHIP,
    PYMTTERM,
    RECEIVED,
    REPORTDATE,
    REPORTNGFN,
    REPORTNGST,
    REQUIRED,
    RESORCDWNF,
    RESORCDWNS,
    RSPDDATE,
    RSPDOCGEN,
    SCHEND,
    SCHSTART,
    SETUPFINSH,
    SETUPSTART,
    SHIP,
    SHIPSCHED,
    STATUSDATE,
    TEARDOWNF,
    TEARDOWNS,
    TO,
    OTHER;

    public String value() {
        return name();
    }

    public static DATETIMEqual fromValue(String v) {
        return valueOf(v);
    }

}
